@@ -80,7 +80,6 @@ require 'specinfra/command/esxi/base/package'
 # RedHat (inherit Linux)
 require 'specinfra/command/redhat'
 require 'specinfra/command/redhat/base'
-require 'specinfra/command/redhat/base/file'
 require 'specinfra/command/redhat/base/host'
 require 'specinfra/command/redhat/base/iptables'
 require 'specinfra/command/redhat/base/package'
@@ -142,10 +141,15 @@ require 'specinfra/command/alpine/base/service'
 # Arch (inherit Linux)
 require 'specinfra/command/arch'
 require 'specinfra/command/arch/base'
-require 'specinfra/command/arch/base/file'
 require 'specinfra/command/arch/base/service'
 require 'specinfra/command/arch/base/package'
 
+# Clear Linux (inherit Linux)
+require 'specinfra/command/clearlinux'
+require 'specinfra/command/clearlinux/base'
+require 'specinfra/command/clearlinux/base/package'
+require 'specinfra/command/clearlinux/base/service'
+
 # CoreOS (inherit Linux)
 require 'specinfra/command/coreos'
 require 'specinfra/command/coreos/base'
@@ -241,6 +245,8 @@ require 'specinfra/command/opensuse/base/service'
 require 'specinfra/command/sles'
 require 'specinfra/command/sles/base'
 require 'specinfra/command/sles/base/service'
+require 'specinfra/command/sles/v11'
+require 'specinfra/command/sles/v11/user'
 require 'specinfra/command/sles/v12'
 require 'specinfra/command/sles/v12/service'
 
@@ -332,6 +338,10 @@ require 'specinfra/command/solaris/v10/host'
 require 'specinfra/command/solaris/v10/package'
 require 'specinfra/command/solaris/v10/user'
 
+# Solaris 11 (inherit Solaris)
+require 'specinfra/command/solaris/v11'
+require 'specinfra/command/solaris/v11/user'
+
 # SmartOS (inherit Solaris)
 require 'specinfra/command/smartos'
 require 'specinfra/command/smartos/base'
